@@ -1,15 +1,12 @@
 from __future__ import with_statement
 
 import os
-from nose.tools import assert_raises, with_setup
+from nose.tools import assert_raises
 
+from webassets import six
 from webassets import Environment
 from webassets.env import RegisterError
 from webassets import Bundle
-from webassets.test import TempEnvironmentHelper
-from webassets.exceptions import ImminentDeprecationWarning
-
-from helpers import check_warnings
 
 
 class TestEnvApi(object):
@@ -49,6 +46,64 @@ class TestEnvApi(object):
         self.m.register('foofighters', b, output="bar")
         assert b in self.m['foofighters'].contents
 
+    def test_register_composed_bundle(self):
+        """Test registering a bundle with `merge=False`
+        """
+        env = Environment('tests')
+
+        env.register(
+            'base1', 'helpers.py', 'test_ext/__init__.py',
+            merge=False,
+            output='build/%(name)s.%(version)s.css'
+        )
+        assert 'base1' not in env
+        assert 'base1/helpers.py' in env
+        assert 'base1/__init__.py' in env
+
+        env.register(
+            '', 'helpers.py', 'test_ext/__init__.py',
+            merge=False,
+            output='build/%(name)s.css'
+        )
+        assert 'helpers.py' in env
+        assert '__init__.py' in env
+        assert env['helpers.py'].output == 'build/helpers.css'
+        assert env['__init__.py'].output == 'build/__init__.css'
+
+        env.register(
+            'base2', 'helper*.*',
+            merge=False,
+            output='build/%(name)s.%(ext)s'
+        )
+        assert 'base2/helpers.py' in env
+        assert env['base2/helpers.py'].output == 'build/helpers.py'
+
+        env.register(
+            'base3', 'test_ext/__init__.py',
+            merge=False,
+            output='build/%(path)s.css'
+        )
+        assert env['base3/__init__.py'].output == 'build/test_ext/__init__.css'
+
+    def test_register_composed_invalid(self):
+        """Test registering a bundle with `merge=False`
+        and invalid options.
+        """
+        env = Environment('tests')
+
+        # No `output`
+        assert_raises(
+            RegisterError, env.register,
+            'base1', 'helpers.py', merge=False
+        )
+
+        # Nested bundle
+        b = Bundle()
+        assert_raises(
+            RegisterError, env.register,
+            'base2', 'helpers.py', b, merge=False, output='a'
+        )
+
     def test_register_invalid_call(self):
         """Test calling self.m.register with an invalid syntax.
         """
@@ -87,7 +142,13 @@ class TestEnvApi(object):
         b = Bundle()
         self.m.register('foo', b)
         assert 'foo' in self.m
-        assert not 'bar' in self.m
+        assert 'bar' not in self.m
+
+    def test_bool_evaluation(self):
+        """Test that environment evaluates to True in a boolean context.
+        """
+        env = Environment()
+        assert env
 
     def test_url_and_directory(self):
         """The url and directory options are a bit special, because they
@@ -162,7 +223,7 @@ class TestSpecialProperties(object):
 
         # Standard string values
         self.m.versions = 'timestamp'
-        assert isinstance(self.m.config['versions'], basestring)
+        assert isinstance(self.m.config['versions'], six.string_types)
         assert isinstance(self.m.versions, Version)
         assert self.m.versions == 'timestamp'   # __eq__
         assert self.m.versions != 'hash'
@@ -211,46 +272,3 @@ class TestSpecialProperties(object):
         # Class assign
         self.m.cache = instance = BaseCache
         assert isinstance(self.m.cache, BaseCache)
-
-
-class TestVersionSystemDeprecations(TempEnvironmentHelper):
-    """With the introduction of the ``Environment.version`` system,
-    some functionality has been deprecated.
-    """
-
-    def test_expire_option(self):
-        # Assigning to the expire option raises a deprecation warning
-        with check_warnings(("", ImminentDeprecationWarning)) as w:
-            self.env.expire = True
-        with check_warnings(("", ImminentDeprecationWarning)):
-            self.env.config['expire'] = True
-            # Reading the expire option raises a warning also.
-        with check_warnings(("", ImminentDeprecationWarning)):
-            x = self.env.expire
-        with check_warnings(("", ImminentDeprecationWarning)):
-            x = self.env.config['expire']
-
-    def test_expire_option_passthrough(self):
-        """While "expire" no longer exists, we attempt to provide an
-        emulation."""
-        with check_warnings(("", ImminentDeprecationWarning)):
-            # Read
-            self.env.url_expire = False
-            assert self.env.expire == False
-            self.env.url_expire = True
-            assert self.env.expire == 'querystring'
-            # Write
-            self.env.expire = False
-            assert self.env.url_expire == False
-            self.env.expire = 'querystring'
-            assert self.env.url_expire == True
-            # "filename" needs to be migrated manually
-            assert_raises(DeprecationWarning, setattr, self.env, 'expire', 'filename')
-
-    def test_updater_option_passthrough(self):
-        """Certain values of the "updater" option have been replaced with
-        auto_build."""
-        with check_warnings(("", ImminentDeprecationWarning)):
-            self.env.auto_build = True
-            self.env.updater = 'never'
-            assert self.env.auto_build == False
